/*
  This brief example show how to set up interrupt vectors for the
  enhanced PIC18 core devices:

  1) The interrupt vector table can be located before or after the
     interrupt functions. It is required to define function prototypes
     when the interrupt vector table is located first (as shown).

  2) Multiple interrupt vector tables can be defined and used in the
     application.

  3) IVTBASE24 is a predefined 24 bit variable (IVTBASEL, IVTBASEH,
     IVTBASEU) that can be used to update the current active interrupt
     vector table,

  4) Each device has its own set of interrupt vectors.

  5) Each interrupt service routine must be defined according to
     the requirements of the actual interrupt.

  6) Each interrupt service routine is terminated by a "RETFIE 1" instruction
     which restores WREG, STATUS, BSR, FSR0H, FSR0L, FSR1H, FSR1L, FSR2H,
     FSR2L, PRODH, PRODL, PCLATH and PCLATU registers from the corresponding
     shadow registers. There are two sets of shadow registers, main context
     and low context. The set retrieved on RETFIE instruction execution
     depends on what the state of operation of the CPU was when RETFIE was
     executed. This allows automatic register restoration from both high and
     low priority interrupts.

  7) MVECEN bit in CONFIG2L must be 1 to enable use of vector table interrupt
*/

/*
  Interrupt Setup Procedure - According to Microchip:
  1. When using interrupt priority levels, set the IPEN bit in INTCON0
     register and then select the user-assigned priority level for the
     interrupt source by writing the control bits in the appropriate IPRx
     Control register.

  2. Clear the Interrupt Flag Status bit associated with the peripheral in the
     associated PIRx Status register.

  3. Enable the interrupt source by setting the interrupt enable control bit
     associated with the source in the appropriate PIEx Control register.

  4. If the vector table is used (MVECEN = 1), then setup the start address
     for the Interrupt Vector Table using the IVTBASE register

  5. Once the IVTBASE is written to, set the Interrupt enable bits in INTCON0
     register.
*/

#if !__EnhancedCore18__
 #error This example is valid only for the enhanced PIC18 core
#endif

#if !defined __CC8E__
 // These definitions are for the MPLAB X GUI only (not compiled)
 #include "C:\Program Files (x86)\bknd\cc8e\defmpx18.h"

 // MPLAB X will read chip specific symbols from the device header file:
 #include "C:\Program Files (x86)\bknd\cc8e\18F57q43.h"
#endif



/*
   Command line option -cgi generates the device-specific interrupt vector
   table. The newest header files contain the required #pragma intSRC_
   definitions or alternatively the SETCC utility version 2 can be used to get
   a device header file. The generated interrupt definitions file will have
   the format "<device>-int.c", for example "18f57q43-int.c". The file will
   only be generated if it does not exist. The file contains 3 main parts:

     a) List of defines to include or exclude specific interrupts
     b) Device specific interrupt vector table
     c) Interrupt functions where user code can be added

   The following code has been copied from the generated "18f57q43-int.c" and
   modified:
*/


#define enable_SWINT_int     0  // Software Interrupt
#define enable_HLVD_int      0  // HLVD Interrupt
#define enable_OSF_int       0  // Oscillator Failure Interrupt
#define enable_CSW_int       0  // Clock Switch Interrupt
#define enable_CLC1_int      0  // CLC1 Interrupt
#define enable_IOC_int       0  // Interrupt on change
#define enable_INT0_int      0  // External Interrupt 0
#define enable_ZCD_int       0  // ZCD Interrupt
#define enable_AD_int        0  // ADC Interrupt
#define enable_ACT_int       0  // Active Clock Tuning Interrupt
#define enable_CMP1_int      0  // Comparator 1 Interrupt
#define enable_SMT1_int      0  // SMT1 Interrupt
#define enable_SMT1PRA_int   0  // SMT1 Period acqusition Interrupt
#define enable_SMT1PRW_int   0  // SMT1 Pulse width acqusition Interrupt
#define enable_ADT_int       0  // ADC Treshold Interrupt
#define enable_DMA1SCNT_int  0  // DMA1 Source count Interrupt
#define enable_DMA1DCNT_int  0  // DMA1 Destination count Interrupt
#define enable_DMA1OR_int    0  // DMA1 Overflow Interrupt
#define enable_DMA1A_int     0  // DMA1 Abort Interrupt
#define enable_SPI1RX_int    0  // SPI1 Receive Interrupt
#define enable_SPI1TX_int    0  // SPI1 Transmit Interrupt
#define enable_SPI1_int      0  // SPI1 Interrupt
#define enable_TMR2_int      1  // Timer2 Interrupt
#define enable_TMR1_int      1  // Timer1 Interrupt
#define enable_TMR1G_int     0  // Timer1 Gate Interrupt
#define enable_CCP1_int      0  // CCP1 Interrupt
#define enable_TMR0_int      0  // Timer0 Interrupt
#define enable_U1RX_int      0  // UART1 Receive Interrupt
#define enable_U1TX_int      0  // UART1 Transmit Interrupt
#define enable_U1E_int       0  // UART1 Error Interrupt
#define enable_U1_int        0  // UART1 Interrupt
#define enable_PWM1PR_int    0  // PWM1 Period Interrupt
#define enable_PWM1_int      0  // PWM1 Interrupt
#define enable_SPI2RX_int    0  // SPI2 Receive Interrupt
#define enable_SPI2TX_int    0  // SPI2 Transmit Interrupt
#define enable_SPI2_int      0  // SPI2 Interrupt
#define enable_TMR3_int      1  // Timer3 Interrupt
#define enable_TMR3G_int     0  // Timer3 Gate Interrupt
#define enable_PWM2PR_int    0  // PWM2 Period Interrupt
#define enable_PWM2_int      0  // PWM2 Interrupt
#define enable_INT1_int      0  // External Interrupt 1
#define enable_CLC2_int      0  // CLC2 Interrupt
#define enable_CWG1_int      0  // CWG1 Interrupt
#define enable_NCO1_int      0  // NCO1 Interrupt
#define enable_DMA2SCNT_int  0  // DMA2 Source count Interrupt
#define enable_DMA2DCNT_int  0  // DMA2 Destination count Interrupt
#define enable_DMA2OR_int    0  // DMA2 Overflow Interrupt
#define enable_DMA2A_int     0  // DMA2 Abort Interrupt
#define enable_I2C1RX_int    0  // I2C1 Receive Interrupt
#define enable_I2C1TX_int    0  // I2C1 Transmit Interrupt
#define enable_I2C1_int      0  // I2C1 Interrupt
#define enable_I2C1E_int     0  // I2C1 Error Interrupt
#define enable_CLC3_int      0  // CLC3 Interrupt
#define enable_PWM3PR_int    0  // PWM3 Period Interrupt
#define enable_PWM3_int      0  // PWM3 Interrupt
#define enable_U2RX_int      0  // UART2 Receive Interrupt
#define enable_U2TX_int      0  // UART2 Transmit Interrupt
#define enable_U2E_int       0  // UART2 Error Interrupt
#define enable_U2_int        0  // UART2 Interrupt
#define enable_TMR5_int      0  // Timer5 Interrupt
#define enable_TMR5G_int     0  // Timer5 Gate Interrupt
#define enable_CCP2_int      0  // CCP2 Interrupt
#define enable_SCAN_int      0  // Scanner Interrupt
#define enable_U3RX_int      0  // UART3 Receive Interrupt
#define enable_U3TX_int      0  // UART3 Transmit Interrupt
#define enable_U3E_int       0  // UART3 Error Interrupt
#define enable_U3_int        0  // UART3 Interrupt
#define enable_CLC4_int      0  // CLC4 Interrupt
#define enable_INT2_int      0  // External Interrupt 2
#define enable_CLC5_int      0  // CLC5 Interrupt
#define enable_CWG2_int      0  // CWG2 Interrupt
#define enable_NCO2_int      0  // NCO2 Interrupt
#define enable_DMA3SCNT_int  0  // DMA3 Source count Interrupt
#define enable_DMA3DCNT_int  0  // DMA3 Destination count Interrupt
#define enable_DMA3OR_int    0  // DMA3 Overflow Interrupt
#define enable_DMA3A_int     0  // DMA3 Abort Interrupt
#define enable_CCP3_int      0  // CCP3 Interrupt
#define enable_CLC6_int      0  // CLC6 Interrupt
#define enable_CWG3_int      0  // CWG3 Interrupt
#define enable_TMR4_int      0  // Timer4 Interrupt
#define enable_DMA4SCNT_int  0  // DMA4 Source count Interrupt
#define enable_DMA4DCNT_int  0  // DMA4 Destination count Interrupt
#define enable_DMA4OR_int    0  // DMA4 Overflow Interrupt
#define enable_DMA4A_int     0  // DMA4 Abort Interrupt
#define enable_U4RX_int      0  // UART4 Receive Interrupt
#define enable_U4TX_int      0  // UART4 Transmit Interrupt
#define enable_U4E_int       0  // UART4 Error Interrupt
#define enable_U4_int        0  // UART4 Interrupt
#define enable_DMA5SCNT_int  0  // DMA5 Source count Interrupt
#define enable_DMA5DCNT_int  0  // DMA5 Destination count Interrupt
#define enable_DMA5OR_int    0  // DMA5 Overflow Interrupt
#define enable_DMA5A_int     0  // DMA5 Abort Interrupt
#define enable_U5RX_int      0  // UART5 Receive Interrupt
#define enable_U5TX_int      0  // UART5 Transmit Interrupt
#define enable_U5E_int       0  // UART5 Error Interrupt
#define enable_U5_int        0  // UART5 Interrupt
#define enable_DMA6SCNT_int  0  // DMA6 Source count Interrupt
#define enable_DMA6DCNT_int  0  // DMA6 Destination count Interrupt
#define enable_DMA6OR_int    0  // DMA6 Overflow Interrupt
#define enable_DMA6A_int     0  // DMA6 Abort Interrupt
#define enable_CLC7_int      0  // CLC7 Interrupt
#define enable_CMP2_int      0  // Comparator 2 Interrupt
#define enable_NCO3_int      0  // NCO3 Interrupt
#define enable_NVM_int       1  // NVM Interrupt
#define enable_CLC8_int      0  // CLC8 Interrupt
#define enable_CRC_int       1  // CRC Interrupt
#define enable_TMR6_int      0  // Timer6 Interrupt


interrupt SWINT_isr( void);
interrupt HLVD_isr( void);
interrupt OSF_isr( void);
interrupt CSW_isr( void);
interrupt CLC1_isr( void);
interrupt IOC_isr( void);
interrupt INT0_isr( void);
interrupt ZCD_isr( void);
interrupt AD_isr( void);
interrupt ACT_isr( void);
interrupt CMP1_isr( void);
interrupt SMT1_isr( void);
interrupt SMT1PRA_isr( void);
interrupt SMT1PRW_isr( void);
interrupt ADT_isr( void);
interrupt DMA1SCNT_isr( void);
interrupt DMA1DCNT_isr( void);
interrupt DMA1OR_isr( void);
interrupt DMA1A_isr( void);
interrupt SPI1RX_isr( void);
interrupt SPI1TX_isr( void);
interrupt SPI1_isr( void);
interrupt TMR2_isr( void);
interrupt TMR1_isr( void);
interrupt TMR1G_isr( void);
interrupt CCP1_isr( void);
interrupt TMR0_isr( void);
interrupt U1RX_isr( void);
interrupt U1TX_isr( void);
interrupt U1E_isr( void);
interrupt U1_isr( void);
interrupt PWM1PR_isr( void);
interrupt PWM1_isr( void);
interrupt SPI2RX_isr( void);
interrupt SPI2TX_isr( void);
interrupt SPI2_isr( void);
interrupt TMR3_isr( void);
interrupt TMR3G_isr( void);
interrupt PWM2PR_isr( void);
interrupt PWM2_isr( void);
interrupt INT1_isr( void);
interrupt CLC2_isr( void);
interrupt CWG1_isr( void);
interrupt NCO1_isr( void);
interrupt DMA2SCNT_isr( void);
interrupt DMA2DCNT_isr( void);
interrupt DMA2OR_isr( void);
interrupt DMA2A_isr( void);
interrupt I2C1RX_isr( void);
interrupt I2C1TX_isr( void);
interrupt I2C1_isr( void);
interrupt I2C1E_isr( void);
interrupt CLC3_isr( void);
interrupt PWM3PR_isr( void);
interrupt PWM3_isr( void);
interrupt U2RX_isr( void);
interrupt U2TX_isr( void);
interrupt U2E_isr( void);
interrupt U2_isr( void);
interrupt TMR5_isr( void);
interrupt TMR5G_isr( void);
interrupt CCP2_isr( void);
interrupt SCAN_isr( void);
interrupt U3RX_isr( void);
interrupt U3TX_isr( void);
interrupt U3E_isr( void);
interrupt U3_isr( void);
interrupt CLC4_isr( void);
interrupt INT2_isr( void);
interrupt CLC5_isr( void);
interrupt CWG2_isr( void);
interrupt NCO2_isr( void);
interrupt DMA3SCNT_isr( void);
interrupt DMA3DCNT_isr( void);
interrupt DMA3OR_isr( void);
interrupt DMA3A_isr( void);
interrupt CCP3_isr( void);
interrupt CLC6_isr( void);
interrupt CWG3_isr( void);
interrupt TMR4_isr( void);
interrupt DMA4SCNT_isr( void);
interrupt DMA4DCNT_isr( void);
interrupt DMA4OR_isr( void);
interrupt DMA4A_isr( void);
interrupt U4RX_isr( void);
interrupt U4TX_isr( void);
interrupt U4E_isr( void);
interrupt U4_isr( void);
interrupt DMA5SCNT_isr( void);
interrupt DMA5DCNT_isr( void);
interrupt DMA5OR_isr( void);
interrupt DMA5A_isr( void);
interrupt U5RX_isr( void);
interrupt U5TX_isr( void);
interrupt U5E_isr( void);
interrupt U5_isr( void);
interrupt DMA6SCNT_isr( void);
interrupt DMA6DCNT_isr( void);
interrupt DMA6OR_isr( void);
interrupt DMA6A_isr( void);
interrupt CLC7_isr( void);
interrupt CMP2_isr( void);
interrupt NCO3_isr( void);
interrupt NVM_isr( void);
interrupt CLC8_isr( void);
interrupt CRC_isr( void);
interrupt TMR6_isr( void);
interrupt default_isr( void);


#define __define_isr( isr_flag, isr_routine) \
#if isr_flag  \
 isr_routine  \
#else         \
 default_isr  \
#endif        \


#if _18F57Q43
const IntVector16 intVectorTable1[] = {
  __define_isr( enable_SWINT_int, SWINT_isr),        // 0, Software Interrupt
  __define_isr( enable_HLVD_int, HLVD_isr),          // 1, HLVD Interrupt
  __define_isr( enable_OSF_int, OSF_isr),            // 2, Oscillator Failure Interrupt
  __define_isr( enable_CSW_int, CSW_isr),            // 3, Clock Switch Interrupt
    default_isr,     // 4
  __define_isr( enable_CLC1_int, CLC1_isr),          // 5, CLC1 Interrupt
    default_isr,     // 6
  __define_isr( enable_IOC_int, IOC_isr),            // 7, Interrupt on change
  __define_isr( enable_INT0_int, INT0_isr),          // 8, External Interrupt 0
  __define_isr( enable_ZCD_int, ZCD_isr),            // 9, ZCD Interrupt
  __define_isr( enable_AD_int, AD_isr),              // 10, ADC Interrupt
  __define_isr( enable_ACT_int, ACT_isr),            // 11, Active Clock Tuning Interrupt
  __define_isr( enable_CMP1_int, CMP1_isr),          // 12, Comparator 1 Interrupt
  __define_isr( enable_SMT1_int, SMT1_isr),          // 13, SMT1 Interrupt
  __define_isr( enable_SMT1PRA_int, SMT1PRA_isr),    // 14, SMT1 Period acqusition Interrupt
  __define_isr( enable_SMT1PRW_int, SMT1PRW_isr),    // 15, SMT1 Pulse width acqusition Interrupt
  __define_isr( enable_ADT_int, ADT_isr),            // 16, ADC Treshold Interrupt
    default_isr,     // 17
    default_isr,     // 18
    default_isr,     // 19
  __define_isr( enable_DMA1SCNT_int, DMA1SCNT_isr),  // 20, DMA1 Source count Interrupt
  __define_isr( enable_DMA1DCNT_int, DMA1DCNT_isr),  // 21, DMA1 Destination count Interrupt
  __define_isr( enable_DMA1OR_int, DMA1OR_isr),      // 22, DMA1 Overflow Interrupt
  __define_isr( enable_DMA1A_int, DMA1A_isr),        // 23, DMA1 Abort Interrupt
  __define_isr( enable_SPI1RX_int, SPI1RX_isr),      // 24, SPI1 Receive Interrupt
  __define_isr( enable_SPI1TX_int, SPI1TX_isr),      // 25, SPI1 Transmit Interrupt
  __define_isr( enable_SPI1_int, SPI1_isr),          // 26, SPI1 Interrupt
  __define_isr( enable_TMR2_int, TMR2_isr),          // 27, Timer2 Interrupt
  __define_isr( enable_TMR1_int, TMR1_isr),          // 28, Timer1 Interrupt
  __define_isr( enable_TMR1G_int, TMR1G_isr),        // 29, Timer1 Gate Interrupt
  __define_isr( enable_CCP1_int, CCP1_isr),          // 30, CCP1 Interrupt
  __define_isr( enable_TMR0_int, TMR0_isr),          // 31, Timer0 Interrupt
  __define_isr( enable_U1RX_int, U1RX_isr),          // 32, UART1 Receive Interrupt
  __define_isr( enable_U1TX_int, U1TX_isr),          // 33, UART1 Transmit Interrupt
  __define_isr( enable_U1E_int, U1E_isr),            // 34, UART1 Error Interrupt
  __define_isr( enable_U1_int, U1_isr),              // 35, UART1 Interrupt
    default_isr,     // 36
    default_isr,     // 37
  __define_isr( enable_PWM1PR_int, PWM1PR_isr),      // 38, PWM1 Period Interrupt
  __define_isr( enable_PWM1_int, PWM1_isr),          // 39, PWM1 Interrupt
  __define_isr( enable_SPI2RX_int, SPI2RX_isr),      // 40, SPI2 Receive Interrupt
  __define_isr( enable_SPI2TX_int, SPI2TX_isr),      // 41, SPI2 Transmit Interrupt
  __define_isr( enable_SPI2_int, SPI2_isr),          // 42, SPI2 Interrupt
    default_isr,     // 43
  __define_isr( enable_TMR3_int, TMR3_isr),          // 44, Timer3 Interrupt
  __define_isr( enable_TMR3G_int, TMR3G_isr),        // 45, Timer3 Gate Interrupt
  __define_isr( enable_PWM2PR_int, PWM2PR_isr),      // 46, PWM2 Period Interrupt
  __define_isr( enable_PWM2_int, PWM2_isr),          // 47, PWM2 Interrupt
  __define_isr( enable_INT1_int, INT1_isr),          // 48, External Interrupt 1
  __define_isr( enable_CLC2_int, CLC2_isr),          // 49, CLC2 Interrupt
  __define_isr( enable_CWG1_int, CWG1_isr),          // 50, CWG1 Interrupt
  __define_isr( enable_NCO1_int, NCO1_isr),          // 51, NCO1 Interrupt
  __define_isr( enable_DMA2SCNT_int, DMA2SCNT_isr),  // 52, DMA2 Source count Interrupt
  __define_isr( enable_DMA2DCNT_int, DMA2DCNT_isr),  // 53, DMA2 Destination count Interrupt
  __define_isr( enable_DMA2OR_int, DMA2OR_isr),      // 54, DMA2 Overflow Interrupt
  __define_isr( enable_DMA2A_int, DMA2A_isr),        // 55, DMA2 Abort Interrupt
  __define_isr( enable_I2C1RX_int, I2C1RX_isr),      // 56, I2C1 Receive Interrupt
  __define_isr( enable_I2C1TX_int, I2C1TX_isr),      // 57, I2C1 Transmit Interrupt
  __define_isr( enable_I2C1_int, I2C1_isr),          // 58, I2C1 Interrupt
  __define_isr( enable_I2C1E_int, I2C1E_isr),        // 59, I2C1 Error Interrupt
    default_isr,     // 60
  __define_isr( enable_CLC3_int, CLC3_isr),          // 61, CLC3 Interrupt
  __define_isr( enable_PWM3PR_int, PWM3PR_isr),      // 62, PWM3 Period Interrupt
  __define_isr( enable_PWM3_int, PWM3_isr),          // 63, PWM3 Interrupt
  __define_isr( enable_U2RX_int, U2RX_isr),          // 64, UART2 Receive Interrupt
  __define_isr( enable_U2TX_int, U2TX_isr),          // 65, UART2 Transmit Interrupt
  __define_isr( enable_U2E_int, U2E_isr),            // 66, UART2 Error Interrupt
  __define_isr( enable_U2_int, U2_isr),              // 67, UART2 Interrupt
  __define_isr( enable_TMR5_int, TMR5_isr),          // 68, Timer5 Interrupt
  __define_isr( enable_TMR5G_int, TMR5G_isr),        // 69, Timer5 Gate Interrupt
  __define_isr( enable_CCP2_int, CCP2_isr),          // 70, CCP2 Interrupt
  __define_isr( enable_SCAN_int, SCAN_isr),          // 71, Scanner Interrupt
  __define_isr( enable_U3RX_int, U3RX_isr),          // 72, UART3 Receive Interrupt
  __define_isr( enable_U3TX_int, U3TX_isr),          // 73, UART3 Transmit Interrupt
  __define_isr( enable_U3E_int, U3E_isr),            // 74, UART3 Error Interrupt
  __define_isr( enable_U3_int, U3_isr),              // 75, UART3 Interrupt
    default_isr,     // 76
  __define_isr( enable_CLC4_int, CLC4_isr),          // 77, CLC4 Interrupt
    default_isr,     // 78
    default_isr,     // 79
  __define_isr( enable_INT2_int, INT2_isr),          // 80, External Interrupt 2
  __define_isr( enable_CLC5_int, CLC5_isr),          // 81, CLC5 Interrupt
  __define_isr( enable_CWG2_int, CWG2_isr),          // 82, CWG2 Interrupt
  __define_isr( enable_NCO2_int, NCO2_isr),          // 83, NCO2 Interrupt
  __define_isr( enable_DMA3SCNT_int, DMA3SCNT_isr),  // 84, DMA3 Source count Interrupt
  __define_isr( enable_DMA3DCNT_int, DMA3DCNT_isr),  // 85, DMA3 Destination count Interrupt
  __define_isr( enable_DMA3OR_int, DMA3OR_isr),      // 86, DMA3 Overflow Interrupt
  __define_isr( enable_DMA3A_int, DMA3A_isr),        // 87, DMA3 Abort Interrupt
  __define_isr( enable_CCP3_int, CCP3_isr),          // 88, CCP3 Interrupt
  __define_isr( enable_CLC6_int, CLC6_isr),          // 89, CLC6 Interrupt
  __define_isr( enable_CWG3_int, CWG3_isr),          // 90, CWG3 Interrupt
  __define_isr( enable_TMR4_int, TMR4_isr),          // 91, Timer4 Interrupt
  __define_isr( enable_DMA4SCNT_int, DMA4SCNT_isr),  // 92, DMA4 Source count Interrupt
  __define_isr( enable_DMA4DCNT_int, DMA4DCNT_isr),  // 93, DMA4 Destination count Interrupt
  __define_isr( enable_DMA4OR_int, DMA4OR_isr),      // 94, DMA4 Overflow Interrupt
  __define_isr( enable_DMA4A_int, DMA4A_isr),        // 95, DMA4 Abort Interrupt
  __define_isr( enable_U4RX_int, U4RX_isr),          // 96, UART4 Receive Interrupt
  __define_isr( enable_U4TX_int, U4TX_isr),          // 97, UART4 Transmit Interrupt
  __define_isr( enable_U4E_int, U4E_isr),            // 98, UART4 Error Interrupt
  __define_isr( enable_U4_int, U4_isr),              // 99, UART4 Interrupt
  __define_isr( enable_DMA5SCNT_int, DMA5SCNT_isr),  // 100, DMA5 Source count Interrupt
  __define_isr( enable_DMA5DCNT_int, DMA5DCNT_isr),  // 101, DMA5 Destination count Interrupt
  __define_isr( enable_DMA5OR_int, DMA5OR_isr),      // 102, DMA5 Overflow Interrupt
  __define_isr( enable_DMA5A_int, DMA5A_isr),        // 103, DMA5 Abort Interrupt
  __define_isr( enable_U5RX_int, U5RX_isr),          // 104, UART5 Receive Interrupt
  __define_isr( enable_U5TX_int, U5TX_isr),          // 105, UART5 Transmit Interrupt
  __define_isr( enable_U5E_int, U5E_isr),            // 106, UART5 Error Interrupt
  __define_isr( enable_U5_int, U5_isr),              // 107, UART5 Interrupt
  __define_isr( enable_DMA6SCNT_int, DMA6SCNT_isr),  // 108, DMA6 Source count Interrupt
  __define_isr( enable_DMA6DCNT_int, DMA6DCNT_isr),  // 109, DMA6 Destination count Interrupt
  __define_isr( enable_DMA6OR_int, DMA6OR_isr),      // 110, DMA6 Overflow Interrupt
  __define_isr( enable_DMA6A_int, DMA6A_isr),        // 111, DMA6 Abort Interrupt
    default_isr,     // 112
  __define_isr( enable_CLC7_int, CLC7_isr),          // 113, CLC7 Interrupt
  __define_isr( enable_CMP2_int, CMP2_isr),          // 114, Comparator 2 Interrupt
  __define_isr( enable_NCO3_int, NCO3_isr),          // 115, NCO3 Interrupt
    default_isr,     // 116
    default_isr,     // 117
    default_isr,     // 118
    default_isr,     // 119
  __define_isr( enable_NVM_int, NVM_isr),            // 120, NVM Interrupt
  __define_isr( enable_CLC8_int, CLC8_isr),          // 121, CLC8 Interrupt
  __define_isr( enable_CRC_int, CRC_isr),            // 122, CRC Interrupt
  __define_isr( enable_TMR6_int, TMR6_isr),          // 123, Timer6 Interrupt
};
#endif


#if enable_SWINT_int
interrupt SWINT_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_HLVD_int
interrupt HLVD_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_OSF_int
interrupt OSF_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_CSW_int
interrupt CSW_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_CLC1_int
interrupt CLC1_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_IOC_int
interrupt IOC_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_INT0_int
interrupt INT0_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_ZCD_int
interrupt ZCD_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_AD_int
interrupt AD_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_ACT_int
interrupt ACT_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_CMP1_int
interrupt CMP1_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_SMT1_int
interrupt SMT1_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_SMT1PRA_int
interrupt SMT1PRA_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_SMT1PRW_int
interrupt SMT1PRW_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_ADT_int
interrupt ADT_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_DMA1SCNT_int
interrupt DMA1SCNT_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_DMA1DCNT_int
interrupt DMA1DCNT_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_DMA1OR_int
interrupt DMA1OR_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_DMA1A_int
interrupt DMA1A_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_SPI1RX_int
interrupt SPI1RX_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_SPI1TX_int
interrupt SPI1TX_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_SPI1_int
interrupt SPI1_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_TMR2_int
interrupt TMR2_isr( void)
{
 // handle the interrupt and clear the interrupt flag
    TMR2IF = 0;
}
#endif


#if enable_TMR1_int
void funcX( void)
{
}
interrupt TMR1_isr( void)
{
 // handle the interrupt and clear the interrupt flag
    funcX();
    TMR1IF = 0;
}
#endif


#if enable_TMR1G_int
interrupt TMR1G_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_CCP1_int
interrupt CCP1_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_TMR0_int
interrupt TMR0_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_U1RX_int
interrupt U1RX_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_U1TX_int
interrupt U1TX_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_U1E_int
interrupt U1E_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_U1_int
interrupt U1_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_PWM1PR_int
interrupt PWM1PR_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_PWM1_int
interrupt PWM1_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_SPI2RX_int
interrupt SPI2RX_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_SPI2TX_int
interrupt SPI2TX_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_SPI2_int
interrupt SPI2_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_TMR3_int
interrupt TMR3_isr( void)
{
 // handle the interrupt and clear the interrupt flag
    TMR3IF = 0;
}
#endif


#if enable_TMR3G_int
interrupt TMR3G_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_PWM2PR_int
interrupt PWM2PR_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_PWM2_int
interrupt PWM2_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_INT1_int
interrupt INT1_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_CLC2_int
interrupt CLC2_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_CWG1_int
interrupt CWG1_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_NCO1_int
interrupt NCO1_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_DMA2SCNT_int
interrupt DMA2SCNT_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_DMA2DCNT_int
interrupt DMA2DCNT_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_DMA2OR_int
interrupt DMA2OR_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_DMA2A_int
interrupt DMA2A_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_I2C1RX_int
interrupt I2C1RX_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_I2C1TX_int
interrupt I2C1TX_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_I2C1_int
interrupt I2C1_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_I2C1E_int
interrupt I2C1E_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_CLC3_int
interrupt CLC3_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_PWM3PR_int
interrupt PWM3PR_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_PWM3_int
interrupt PWM3_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_U2RX_int
interrupt U2RX_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_U2TX_int
interrupt U2TX_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_U2E_int
interrupt U2E_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_U2_int
interrupt U2_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_TMR5_int
interrupt TMR5_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_TMR5G_int
interrupt TMR5G_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_CCP2_int
interrupt CCP2_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_SCAN_int
interrupt SCAN_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_U3RX_int
interrupt U3RX_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_U3TX_int
interrupt U3TX_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_U3E_int
interrupt U3E_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_U3_int
interrupt U3_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_CLC4_int
interrupt CLC4_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_INT2_int
interrupt INT2_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_CLC5_int
interrupt CLC5_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_CWG2_int
interrupt CWG2_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_NCO2_int
interrupt NCO2_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_DMA3SCNT_int
interrupt DMA3SCNT_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_DMA3DCNT_int
interrupt DMA3DCNT_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_DMA3OR_int
interrupt DMA3OR_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_DMA3A_int
interrupt DMA3A_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_CCP3_int
interrupt CCP3_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_CLC6_int
interrupt CLC6_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_CWG3_int
interrupt CWG3_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_TMR4_int
interrupt TMR4_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_DMA4SCNT_int
interrupt DMA4SCNT_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_DMA4DCNT_int
interrupt DMA4DCNT_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_DMA4OR_int
interrupt DMA4OR_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_DMA4A_int
interrupt DMA4A_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_U4RX_int
interrupt U4RX_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_U4TX_int
interrupt U4TX_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_U4E_int
interrupt U4E_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_U4_int
interrupt U4_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_DMA5SCNT_int
interrupt DMA5SCNT_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_DMA5DCNT_int
interrupt DMA5DCNT_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_DMA5OR_int
interrupt DMA5OR_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_DMA5A_int
interrupt DMA5A_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_U5RX_int
interrupt U5RX_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_U5TX_int
interrupt U5TX_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_U5E_int
interrupt U5E_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_U5_int
interrupt U5_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_DMA6SCNT_int
interrupt DMA6SCNT_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_DMA6DCNT_int
interrupt DMA6DCNT_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_DMA6OR_int
interrupt DMA6OR_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_DMA6A_int
interrupt DMA6A_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_CLC7_int
interrupt CLC7_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_CMP2_int
interrupt CMP2_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_NCO3_int
interrupt NCO3_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_NVM_int
interrupt NVM_isr( void)
{
 // handle the interrupt and clear the interrupt flag
    NVMIF = 0;
}
#endif


#if enable_CLC8_int
interrupt CLC8_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


#if enable_CRC_int
interrupt CRC_isr( void)
{
 // handle the interrupt and clear the interrupt flag
    CRCIF = 0;
}
#endif


#if enable_TMR6_int
interrupt TMR6_isr( void)
{
 // handle the interrupt and clear the interrupt flag
}
#endif


interrupt default_isr( void)
{
 // exception handling
}

//*********************************************
// END OF GENERATED AND MODIFIED INTERRUPT CODE
//*********************************************



#if !REGNAME_BITNAME
 #define INTCON0_GIE        GIE
 #define IVTLOCK_IVTLOCKED  IVTLOCKED
#endif

/*
  It is not required to set IVTBASE when the interrupt
  vector table is located at default address 8.
*/
void setIVTBASE( void)
{
    INTCON0_GIE = 0;  // Disable interrupts

    // Required sequence to unlock IVTBASE
    IVTLOCK = 0x55;
    IVTLOCK = 0xAA;
    IVTLOCK_IVTLOCKED = 0;

    IVTBASE24 = (uns24) intVectorTable1;

    // Required sequence to lock IVTBASE
    IVTLOCK = 0x55;
    IVTLOCK = 0xAA;
    IVTLOCK_IVTLOCKED = 1;

    INTCON0_GIE = 1;  // Enable interrupts
}



void main( void)
{
    // add code as required

    setIVTBASE();
}



